@@ -85,7 +85,7 @@ struct updateInfo
 
     static int compare(const updateInfo &a, const updateInfo&b)
     {
-        QRegExp regexp("(\\d+)\\.(\\d+)\\.(\\d+)(-.*)?");
+        QRegExp regexp("^(\\d+)\\.(\\d+)\\.(\\d+)(-.*)?$");
         if (regexp.indexIn(a.version) > -1 && regexp.indexIn((b.version)) > -1)
         {
             regexp.indexIn(a.version);
