@@ -48,8 +48,9 @@ class video_dailymotion : public video
         bool setUrl(QString);
 
     private:
-        QString getQualityUrl(QString json, QString quality);
+        QString getQualityUrl(QString json, QString quality, QString type = "video/mp4");
         QString getProperty(QString json, QString property);
+        QString downloading;
 
     public slots:
         virtual void parseVideo(QString html);
